@@ -13,11 +13,19 @@ from core.documentation import (
     description_name_version_0,
     namespace_name_version_0,
     urls_name_version_0,
+    title_name_version_0_private,
+    description_name_version_0_private,
+    namespace_name_version_0_private,
+    urls_name_version_0_private,
 )
 
 # PUBLIC URLS name_version
 urls_name_version_0 = [
-    url(r'^v1/', include(public_urls)),
+    url(r'^name_version/', include(public_urls)),
+]
+# PRIVATE URLS name_version
+urls_name_version_0_private = [
+    url(r'^name_version/', include(private_urls)),
 ]
 
 # DOCUMENTATION URLS name_version
@@ -26,6 +34,10 @@ doc_patterns = [
         patterns=urls_name_version_0,
         description=description_name_version_0,
         namespace=namespace_name_version_0)),
+    url(r'^private', include_docs_urls(title=title_name_version_0_private,
+        patterns=urls_name_version_0_private,
+        description=description_name_version_0_private,
+        namespace=namespace_name_version_0_private)),
 ] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
 
 # GENERAL URLS name_version
